@@ -308,7 +308,7 @@ options_tree = {
     },
     'instance_type': {
         'Section': 'EC2',
-        'Prompt': 'EC2 Instance Size',
+        'Prompt': 'EC2 Instance Size:',
         'Help': 'm1.large | m1.xlarge | m2.xlarge | m2.2xlarge | m2.4xlarge'
     },
     'noprompts':{
@@ -394,7 +394,11 @@ def check_cascading_options(option, type_check=False, choices=False, password=Fa
 
 
 def main():
+    print "Using configuration file: %s" % config.get('Internal', 'last_location')
+    print
     print "Welcome to DataStax' Cassandra Cluster Launcher!"
+    print "    The easiest way to get Apache Cassandra up and running in Amazon's EC2"
+    print "    in under 5 minutes!"
     print
 
     global cli_options
